@@ -1,13 +1,15 @@
 from metricflow_to_zenlytic.metricflow_to_zenlytic import (
-    load_mf_project,
     convert_mf_project_to_zenlytic_project,
+    load_mf_project,
 )
-from .project_reader_base import ProjectReaderBase
+
 from metrics_layer.core.exceptions import QueryError
 
+from .project_reader_base import ProjectReaderBase
+
 
 class MetricflowProjectReader(ProjectReaderBase):
-    def load(self) -> None:
+    def load(self) -> tuple:
         if self.dbt_project is None:
             raise QueryError("No dbt project found")
 
@@ -24,4 +26,4 @@ class MetricflowProjectReader(ProjectReaderBase):
         models, views = convert_mf_project_to_zenlytic_project(
             metricflow_project, self.profile_name, self.profile_name
         )
-        return models, views, []
+        return models, views, [], []
